"""MongoDB Parameter Constants (MongoArgs)"""
MONGO_USERNAME = 'MONGO_USERNAME'
MONGO_PASSWORD = 'MONGO_PASSWORD'
MONGO_HOST = 'MONGO_HOST'
MONGO_PORT = 'MONGO_PORT'
MONGO_DBNAME = 'MONGO_DBNAME'
MONGO_REPLICA_SET = 'MONGO_REPLICA_SET'

"""Microsoft SQL Server Parameter Constants (MSSqlArgs)"""
MSSQL_USERNAME = 'MSSQL_USERNAME'
MSSQL_PASSWORD = 'MSSQL_PASSWORD'
MSSQL_HOST = 'MSSQL_HOST'
MSSQL_PORT = 'MSSQL_PORT'
MSSQL_DBNAME = 'MSSQL_DBNAME'

"""PostgreSQL Parameter Constants (PostgreSQLArgs)"""
POSTGRESQL_USERNAME = 'POSTGRESQL_USERNAME'
POSTGRESQL_PASSWORD = 'POSTGRESQL_PASSWORD'
POSTGRESQL_HOST = 'POSTGRESQL_HOST'
POSTGRESQL_PORT = 'POSTGRESQL_PORT'
POSTGRESQL_DBNAME = 'POSTGRESQL_DBNAME'

"""Snowflake Parameter Constants (SnowflakeArgs)"""
SNOWFLAKE_ENV = 'SNOWFLAKE_ENV'
SNOWFLAKE_USERNAME = 'SNOWFLAKE_USERNAME'
SNOWFLAKE_PASSWORD = 'SNOWFLAKE_PASSWORD'
SNOWFLAKE_ACCOUNT = 'SNOWFLAKE_ACCOUNT'
SNOWFLAKE_WAREHOUSE = 'SNOWFLAKE_WAREHOUSE'
SNOWFLAKE_ROLE = 'SNOWFLAKE_ROLE'

"""AWS Parameter Constants (AwsArgs, S3Args)"""
AWS_KEY = 'AWS_KEY'
AWS_SECRET = 'AWS_SECRET'

"""S3 Parameter Constants (S3Args)"""
AWS_S3_BUCKET = 'AWS_S3_BUCKET'
